/**
 * WordPress dependencies
 */
import * as React from '@safe-wordpress/element';

/**
 * External dependencies
 */
import { Controlled as CodeMirror } from 'react-codemirror2';

import 'codemirror/addon/edit/closebrackets';
import 'codemirror/addon/edit/closetag';
import 'codemirror/addon/hint/show-hint';
import 'codemirror/addon/hint/css-hint';
import 'codemirror/addon/selection/active-line';

import 'codemirror/mode/css/css';

import 'codemirror/lib/codemirror.css';
import 'codemirror/addon/hint/show-hint.css';

export type CssEditorProps = {
	readonly className?: string;
	readonly value: string;
	readonly onChange: ( value: string ) => void;
};

export const CssEditor = ( {
	className,
	value,
	onChange,
}: CssEditorProps ): JSX.Element => (
	<CodeMirror
		className={ className }
		value={ value }
		onBeforeChange={ ( _, __, newValue ) => {
			onChange( newValue );
		} }
		options={ {
			autoCloseBrackets: true,
			autoCloseTags: true,
			lineNumbers: true,
			matchBrackets: true,
			mode: 'text/css',
			styleActiveLine: true,
			extraKeys: { 'Ctrl-Space': 'autocomplete' },
		} }
	/>
);
