<?php

namespace Nelio_AB_Testing\WooCommerce\Experiment_Library\Product_Experiment\Editor;

defined( 'ABSPATH' ) || exit;

use \add_filter;
use \add_meta_box;


function add_product_data_metabox() {
	add_meta_box(
		'nab-product-data',
		__( 'Product data', 'woocommerce' ),
		__NAMESPACE__ . '\render_product_data_metabox',
		'nab_alt_product',
		'normal',
		'high',
		array(
			'__back_compat_meta_box' => true,
		)
	);
}//end add_product_data_metabox()
add_action( 'add_meta_boxes', __NAMESPACE__ . '\add_product_data_metabox' );


function render_product_data_metabox( $post ) {
	$product_id = $post->ID;
	$original   = get_original_product( $product_id );
	if ( empty( $original ) ) {
		echo esc_html_x( 'Something went wrong. Tested product could not be found.', 'text', 'nelio-ab-testing' );
		return;
	}//end if

	wp_nonce_field( "nab_save_product_data_{$product_id}", 'nab_product_data_nonce' );
	echo '<div id="nab-product-data-root"></div>';

	if ( $original->get_type() !== 'variable' ) {
		$settings = array(
			'type'          => 'regular',
			'originalPrice' => $original->get_regular_price(),
			'regularPrice'  => get_post_meta( $product_id, '_regular_price', true ),
			'salePrice'     => get_post_meta( $product_id, '_sale_price', true ),
		);
	} else {
		$variation_data = get_post_meta( $product_id, '_nab_variation_data', true );
		if ( ! is_array( $variation_data ) ) {
			$variation_data = array();
		}//end if
		$settings = array(
			'type'       => 'variable',
			'variations' => array_map(
				function( $wc_variation ) use ( &$variation_data ) {
					$variation = $wc_variation->get_id();
					$variation = isset( $variation_data[ $variation ] ) ? $variation_data[ $variation ] : array();
					$variation = wp_parse_args(
						$variation,
						array(
							'imageId'      => 0,
							'regularPrice' => '',
							'salePrice'    => '',
							'description'  => '',
						)
					);
					return array(
						'id'            => $wc_variation->get_id(),
						'name'          => implode( ',', $wc_variation->get_attributes() ),
						'imageId'       => absint( $variation['imageId'] ),
						'originalPrice' => $wc_variation->get_regular_price(),
						'regularPrice'  => $variation['regularPrice'],
						'salePrice'     => $variation['salePrice'],
						'description'   => $variation['description'],
					);
				},
				array_filter( array_map( 'wc_get_product', $original->get_children() ) )
			),
		);
	}//end if

	printf(
		'<script type="text/javascript">nab.initProductDataMetabox( %s );</script>',
		wp_json_encode( $settings )
	);
}//end render_product_data_metabox()


function render_variation_fields( $product_id, $variation ) {
	$varid = $variation->get_id();
	$value = function( $value ) {
		printf( '"%s"', esc_attr( $value ) );
	};
	$id    = function( $name ) use ( $varid, &$value ) {
		$value( "nab_product_variation_{$varid}_{$name}" );
	};
	$name  = function( $attr ) use ( $varid, &$value ) {
		$value( "nab_product_variation[{$varid}][{$attr}]" );
	};
	?>
	<div class="nab-product-variation">
		<div class="nab-product-variation__title">
			<?php
			printf( '<strong>#%d</strong> %s', esc_html( $varid ), esc_html( implode( ',', $variation->get_attributes() ) ) );
			?>
		</div>
		<div class="nab-product-variation__attributes">
			<div class="nab-product-variation__image">
				<input
					type="text"
					name=<?php $name( 'image_id' ); ?>
					value=""
				/>
			</div>
			<div class="nab-product-variation__pricing">
				<input
					id=<?php $id( 'regular_price' ); ?>
					type="text"
					name=<?php $name( 'regular_price' ); ?>
					value=""
					placeholder=<?php $value( $variation->get_regular_price() ); ?>
				/>
				<input
					type="text"
					name=<?php $name( 'sale_price' ); ?>
					value=""
				/>
			</div>
		</div>
	</div>
	<?php
}//end render_variation_fields()


function save_product_data( $post_id ) {
	if ( ! function_exists( 'wc_get_product' ) ) {
		return;
	}//end if

	if ( 'nab_alt_product' !== get_post_type( $post_id ) ) {
		return;
	}//end if

	if ( wp_is_post_revision( $post_id ) || wp_is_post_autosave( $post_id ) ) {
		return;
	}//end if

	if ( ! isset( $_POST['nab_product_data_nonce'] ) ) {
		return;
	}//end if

	$nonce = sanitize_text_field( wp_unslash( $_POST['nab_product_data_nonce'] ) );
	if ( ! wp_verify_nonce( $nonce, "nab_save_product_data_{$post_id}" ) ) {
		return;
	}//end if

	if ( isset( $_POST['nab_regular_price'] ) ) {
		$price = sanitize_text_field( $_POST['nab_regular_price'] );
		update_post_meta( $post_id, '_regular_price', $price );
	}//end if

	if ( isset( $_POST['nab_sale_price'] ) ) {
		$price = sanitize_text_field( $_POST['nab_sale_price'] );
		update_post_meta( $post_id, '_sale_price', $price );
	}//end if

	$product = get_original_product( $post_id );
	if ( ! empty( $product ) && isset( $_POST['nab_variation_data'] ) && is_array( $_POST['nab_variation_data'] ) ) {
		$children       = $product->get_children();
		$variation_data = array_map(
			function( $id, $values ) use ( &$children ) {
				$id = absint( $id );
				if ( ! in_array( $id, $children, true ) ) {
					return false;
				}//end if
				return array(
					'id'           => $id,
					'imageId'      => isset( $values['imageId'] ) ? absint( $values['imageId'] ) : 0,
					'regularPrice' => isset( $values['regularPrice'] ) ? sanitize_text_field( $values['regularPrice'] ) : '',
					'salePrice'    => isset( $values['salePrice'] ) ? sanitize_text_field( $values['salePrice'] ) : '',
					'description'  => isset( $values['description'] ) ? sanitize_textarea_field( $values['description'] ) : '',
				);
			},
			array_keys( $_POST['nab_variation_data'] ), // phpcs:ignore
			array_values( $_POST['nab_variation_data'] ) // phpcs:ignore
		);
		$variation_data = array_filter( $variation_data );
		$variation_data = array_combine( wp_list_pluck( $variation_data, 'id' ), $variation_data );
		update_post_meta( $post_id, '_nab_variation_data', $variation_data );
	}//end if

}//end save_product_data()
add_action( 'save_post', __NAMESPACE__ . '\save_product_data' );


function get_original_product( $alternative_id ) {
	$experiment_id = absint( get_post_meta( $alternative_id, '_nab_experiment', true ) );
	if ( empty( $experiment_id ) ) {
		return false;
	}//end if

	$experiment = nab_get_experiment( $experiment_id );
	if ( is_wp_error( $experiment ) ) {
		return false;
	}//end if

	$original_id = absint( $experiment->get_tested_element() );
	if ( empty( $original_id ) ) {
		return false;
	}//end if
	
	$original = \wc_get_product( $original_id );
	if ( empty( $original ) ) {
		return false;
	}//end if

	return $original;
}//end get_original_product()
