<?php
/**
 * Nelio A/B Testing array helpers.
 *
 * @package    Nelio_AB_Testing
 * @subpackage Nelio_AB_Testing/includes/utils/functions
 * @author     David Aguilera <david.aguilera@neliosoftware.com>
 * @since      5.4.0
 */

/**
 * Checks if a predicate holds true for all the elements in an array.
 *
 * @param callable $predicate Boolean function that takes one item of the array at a time.
 * @param array    $array     Array of items.
 *
 * @return boolean whether the preciate holds true for all the elements in an array.
 *
 * @since 5.4.0
 */
function nab_every( $predicate, $array ) {
	foreach ( $array as $item ) {
		if ( ! call_user_func( $predicate, $item ) ) {
			return false;
		}//end if
	}//end foreach
	return true;
}//end nab_every()

/**
 * Checks if a predicate holds true for any element in an array.
 *
 * @param callable $predicate Boolean function that takes one item of the array at a time.
 * @param array    $array     Array of items.
 *
 * @return boolean whether the preciate holds true for any element in an array.
 *
 * @since 5.4.0
 */
function nab_some( $predicate, $array ) {
	foreach ( $array as $item ) {
		if ( call_user_func( $predicate, $item ) ) {
			return true;
		}//end if
	}//end foreach
	return false;
}//end nab_some()

/**
 * Checks if a predicate holds true for none of the elements in an array.
 *
 * @param callable $predicate Boolean function that takes one item of the array at a time.
 * @param array    $array     Array of items.
 *
 * @return boolean whether the preciate holds true for none of the elements in an array.
 *
 * @since 5.4.0
 */
function nab_none( $predicate, $array ) {
	return ! nab_some( $predicate, $array );
}//end nab_none()
